@@ -18,7 +18,7 @@
 #' @param t values of argument t where K-function will be evaluated. optional.
 #' @param nxy pixel array dimensions. optional.
 #' @import spatstat stlnpp
-#' @return A list of class \code{Klista}.
+#' @return A list of class \code{lista}.
 #' The objects are of class \code{sumstlpp} (Moradi and Mateu, 2020).
 #' @export
 #'
@@ -34,7 +34,7 @@
 #' df_net <- data.frame(x = runif(25, 0, 0.85), y = runif(25, 0, 0.85), t = runif(25))
 #' stlp1 <- stp(df_net, L = chicagonet)
 #' lambda <- rep(diff(range(stlp1$df$x)) * diff(range(stlp1$df$y))
-#'  * diff(range(stlp1$df$t)) / volume(stlp1$L),
+#'  * diff(range(stlp1$df$t)) / spatstat.geom::volume(stlp1$L),
 #' nrow(stlp1$df))
 #'
 #' k <- localSTLKinhom(stlp1, lambda = lambda, normalize = TRUE)
@@ -51,6 +51,8 @@ localSTLKinhom <- function(x, lambda = lambda, normalize = FALSE, r = NULL, t =
 {
   if (!inherits(x, "stlp"))
     stop("x should be from class stlp")
+  
+  x$L <- spatstat.linnet::as.linnet(x$L, sparse = FALSE)
 
   X <- as.stlpp(x)
 
